@@ -37,6 +37,10 @@
 --     "varname": "tag",
 --     ...
 --   },
+--   "share": {
+--     "varname": "tag",
+--     ...
+--   },
 --   "script": {
 --     "on|off|run|change": "script",
 --      ...
@@ -92,9 +96,13 @@ function cheat.startplugin()
 		local newcheats = {}
 		local file = emu.file(manager:machine():options().entries.cheatpath:value():gsub("([^;]+)", "%1;%1/cheat") , 1)
 		if emu.softname() ~= "" then
-			for name, image in pairs(manager:machine().images) do
-				if image:exists() and image:software_list_name() ~= "" then
-					filename = image:software_list_name() .. "/" .. emu.softname()
+			if emu.softname():find(":") then
+				filename = emu.softname():gsub(":", "/")
+			else
+				for name, image in pairs(manager:machine().images) do
+					if image:exists() and image:software_list_name() ~= "" then
+						filename = image:software_list_name() .. "/" .. emu.softname()
+					end
 				end
 			end
 		end
@@ -477,6 +485,16 @@ function cheat.startplugin()
 				cheat.cheat_env[name] = emu.item(ram.items["0/m_pointer"])
 			end
 		end
+		if cheat.share then
+			for name, tag in pairs(cheat.share) do
+				local share = manager:machine():memory().shares[tag]
+				if not share then
+					cheat_error(cheat, "missing share " .. share)
+					return
+				end
+				cheat.cheat_env[name] = share
+			end
+		end
 		local param = cheat.parameter
 		if not param then
 			return
